summaryrefslogtreecommitdiff
path: root/src/tangara/lua/file_iterator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tangara/lua/file_iterator.cpp')
-rw-r--r--src/tangara/lua/file_iterator.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tangara/lua/file_iterator.cpp b/src/tangara/lua/file_iterator.cpp
index 3afc57aa..d0eb0bae 100644
--- a/src/tangara/lua/file_iterator.cpp
+++ b/src/tangara/lua/file_iterator.cpp
@@ -11,7 +11,7 @@
#include "ff.h"
#include "drivers/spi.hpp"
-namespace database {
+namespace lua {
[[maybe_unused]] static const char* kTag = "FileIterator";
@@ -84,4 +84,4 @@ auto FileIterator::iterate(bool reverse) -> bool {
return true;
}
-} // namespace database \ No newline at end of file
+} // namespace lua \ No newline at end of file